pub struct PrettyCompactFormatter { /* private fields */ }Expand description
The formatter.
The PrettyCompactFormatter type implements a pretty serde_json
formatter which tries to be as compact as possible. This can increase the
readability of formatted JSON.
Basic usage
-
Use
PrettyCompactFormatter::new()to create a formatter with a set of default rules.Defaults are:
- indentation: 2 characters
- maximum line length: 120 characters
-
Use
PrettyCompactFormatter::no_rules()without any rules.Without any further applied configuration it acts as a plain pretty formatter.
Configuration
- Change the indentation with
PrettyCompactFormatter::with_indent.
use json_pretty_compact::PrettyCompactFormatter;
let formatter = PrettyCompactFormatter::new().with_indent(4);- Change the maximum line length length with
PrettyCompactFormatter::with_max_line_length.
use json_pretty_compact::PrettyCompactFormatter;
let formatter = PrettyCompactFormatter::new().with_max_line_length(80);Implementations
Sourceimpl PrettyCompactFormatter
impl PrettyCompactFormatter
Sourcepub fn new() -> PrettyCompactFormatter
pub fn new() -> PrettyCompactFormatter
Creates a PrettyCompactFormatter with a set of default rules.
Sourcepub fn no_rules() -> PrettyCompactFormatter
pub fn no_rules() -> PrettyCompactFormatter
Creates a PrettyCompactFormatter without any rules applied.
Sourcepub fn with_indent(self, indent: u32) -> Self
pub fn with_indent(self, indent: u32) -> Self
Changes the indentation to the given value.
Sourcepub fn with_max_line_length(self, len: u32) -> Self
pub fn with_max_line_length(self, len: u32) -> Self
Changes the maximum line length to the given value.